Package: lmhelprs
Title: Helper Functions for Linear Model Analysis
Version: 0.4.3
Authors@R: 
    c(person(given = "Shu Fai",
             family = "Cheung",
             role = c("aut", "cre"),
             email = "shufai.cheung@gmail.com",
             comment = c(ORCID = "0000-0002-9871-9448")))
Description: A collection of helper functions for multiple
  regression models fitted by lm(). Most of them are simple
  functions for simple tasks which can be done with coding,
  but may not be easy for occasional users of R. Most of
  the tasks addressed are those sometimes needed when
  using the 'manymome' package (Cheung and Cheung, 2023,
  <doi:10.3758/s13428-023-02224-z>) and 'stdmod' package
  (Cheung, Cheung, Lau, Hui, and Vong, 2022,
  <doi:10.1037/hea0001188>). However, they can also be used
  in other scenarios.
URL: https://sfcheung.github.io/lmhelprs/
BugReports: https://github.com/sfcheung/lmhelprs/issues
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown, tinytest, semPlot
VignetteBuilder: knitr
Depends: R (>= 2.10)
LazyData: true
Imports: stats
NeedsCompilation: no
Packaged: 2025-05-03 18:36:59 UTC; shufa
Author: Shu Fai Cheung [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9871-9448>)
Maintainer: Shu Fai Cheung <shufai.cheung@gmail.com>
Repository: CRAN
Date/Publication: 2025-05-04 04:30:02 UTC
Built: R 4.3.3; ; 2025-05-04 05:32:36 UTC; unix
