# Generated by roxygen2: do not edit by hand

S3method(print,hierarchical_lm)
S3method(print,lm_list_lmhelprs)
S3method(print,summary_lm_list_lmhelprs)
S3method(summary,lm_list_lmhelprs)
export(hierarchical)
export(hierarchical_lm)
export(highest_order)
export(lm_list_to_partable)
export(many_lm)
export(test_highest)
